@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -41,7 +41,7 @@ from lollypop.player import Player
 from lollypop.inhibitor import Inhibitor
 from lollypop.art import Art
 from lollypop.logger import Logger
-from lollypop.helper_spotify import SpotifyHelper
+from lollypop.search_spotify import SpotifySearch
 from lollypop.sqlcursor import SqlCursor
 from lollypop.settings import Settings
 from lollypop.database_albums import AlbumsDatabase
@@ -200,7 +200,7 @@ class Application(Gtk.Application, ApplicationActions):
         self.art = Art()
         self.art.update_art_size()
         self.art.clean_old_artwork()
-        self.spotify = SpotifyHelper()
+        self.spotify = SpotifySearch()
         if not self.settings.get_value("disable-mpris"):
             from lollypop.mpris import MPRIS
             MPRIS(self)
