@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2019 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -22,7 +22,7 @@ from lollypop.objects_album import Album
 from lollypop.logger import Logger
 from lollypop.downloader_art import ArtDownloader
 from lollypop.define import CACHE_PATH, TMP_PATH, STORE_PATH, App, StorageType
-from lollypop.utils import create_dir
+from lollypop.utils import create_dir, emit_signal
 
 from time import sleep
 from shutil import rmtree
@@ -85,6 +85,7 @@ class Art(BaseArt, AlbumArt, ArtistArt, RadioArt, ArtDownloader):
             for path in pathes:
                 f = Gio.File.new_for_path(path)
                 f.delete(None)
+            emit_signal(self, "artwork-cleared", name, prefix)
         except Exception as e:
             Logger.error("Art::remove_artwork_from_cache(): %s" % e)
 
